@@ -197,7 +197,8 @@ def closelog():
 def db_connect():
 	for x in range(0,255):
 		try:
-			db = MySQLdb.connect(host=mysql_host, user=mysql_user, passwd=mysql_password, db=mysql_db)
+#			db = MySQLdb.connect(host=mysql_host, user=mysql_user, passwd=mysql_password, db=mysql_db)
+			db = MySQLdb.connect(charset='utf8', init_command='SET NAMES UTF8', host=mysql_host, user=mysql_user, passwd=mysql_password, db=mysql_db)
 			#log("db_connect finished on iteration %d" % x)
 			return db
 		except Exception as ex:
@@ -384,21 +385,30 @@ def extractMessageFromEmail(emailText):
 	textSubject = msg['subject']
 	#textSubject = email.header.decode_header(textSubject)
 
-	## Grab the text version of the email. In the get_payload,
-	## be sure to decode for any base64 content
-	for part in msg.walk():
-		if 'multipart/alternative' in part.get_content_type():
-			for subpart in part.walk():
-				if 'text/plain' in subpart.get_content_type():
-					textEmail = subpart.get_payload(decode=True)
-					break;
-		elif 'text/plain' in part.get_content_type():
-			textEmail = part.get_payload(decode=True)
-			break;
+	## Grab the text version of the email.
+	textEmail = u""
+	if msg.is_multipart():
+		htmlEmail = None
+		for part in msg.get_payload():
+
+			if part.get_content_charset() is None:
+				# We cannot know the character set, so return decoded "something"
+				text = part.get_payload(decode=True)
+				continue
+
+			charset = part.get_content_charset()
+
+			if part.get_content_type() == 'text/plain':
+				textEmail = unicode(part.get_payload(decode=True), str(charset), "ignore")
+
+			if part.get_content_type() == 'text/html':
+				html = unicode(part.get_payload(decode=True), str(charset), "ignore")
+
+	else:
+		textEmail = unicode(part.get_payload(decode=True), str(charset), "ignore")
 
 	return textEmail, textSubject, emailFromAddress, emailToAddress
 
-
 def getAttachments(emailText):
 	msg = email.message_from_string(emailText)
 	attachments = _getAttachments(msg)
